
# q-expansion of newform 6.26.a.b, downloaded from the LMFDB on 03 May 2024.

# We generate the q-expansion using the Hecke eigenvalues a_p at the primes.
# Each a_p is given as a linear combination
# of the following basis for the coefficient ring.

def make_data():

    from sage.all import prod, floor, prime_powers, gcd, QQ, primes_first_n, next_prime, RR

    def discrete_log(elts, gens, mod):
        # algorithm 2.2, page 16 of https://arxiv.org/abs/0903.2785
        def table_gens(gens, mod):
            T = [1]
            n = len(gens)
            r = [None]*n
            s = [None]*n
            for i in range(n):
                beta = gens[i]
                r[i] = 1
                N = len(T)
                while beta not in T:
                    for Tj in T[:N]:
                        T.append((beta*Tj) % mod)
                    beta = (beta*gens[i]) % mod
                    r[i] += 1
                s[i] = T.index(beta)
            return T, r, s
        T, r, s = table_gens(gens, mod)
        n = len(gens)
        N = [ prod(r[:j]) for j in range(n) ]
        Z = lambda s: [ (floor(s/N[j]) % r[j]) for j in range(n)]
        return [Z(T.index(elt % mod)) for elt in elts]
    def extend_multiplicatively(an):
        for pp in prime_powers(len(an)-1):
            for k in range(1, (len(an) - 1)//pp + 1):
                if gcd(k, pp) == 1:
                    an[pp*k] = an[pp]*an[k]
    from sage.all import PolynomialRing, NumberField
    R = PolynomialRing(QQ, "x")
    f = R(poly_data)
    K = NumberField(f, "a")
    betas = [K.gens()[0]**i for i in range(len(poly_data))]
    convert_elt_to_field = lambda elt: sum(c*beta for c, beta in zip(elt, betas))
    # convert aps to K elements
    primes = primes_first_n(len(aps_data))
    good_primes = [p for p in primes if not p.divides(level)]
    aps = map(convert_elt_to_field, aps_data)
    if not hecke_ring_character_values:
        # trivial character
        char_values = dict(zip(good_primes, [1]*len(good_primes)))
    else:
        gens = [elt[0] for elt in hecke_ring_character_values]
        gens_values = [convert_elt_to_field(elt[1]) for elt in hecke_ring_character_values]
        char_values = dict([(
            p,prod(g**k for g, k in zip(gens_values, elt)))
            for p, elt in zip(good_primes, discrete_log(good_primes, gens, level))
            ])
    an_list_bound = next_prime(primes[-1])
    an = [0]*an_list_bound
    an[1] = 1
    
    from sage.all import PowerSeriesRing
    PS = PowerSeriesRing(K, "q")
    for p, ap in zip(primes, aps):
        if p.divides(level):
            euler_factor = [1, -ap]
        else:
            euler_factor = [1, -ap, p**(weight - 1) * char_values[p]]
        k = RR(an_list_bound).log(p).floor() + 1
        foo = (1/PS(euler_factor)).padded_list(k)
        for i in range(1, k):
            an[p**i] = foo[i]
    extend_multiplicatively(an)
    return PS(an)
level = 6
weight = 26
poly_data = [0, 1]

# The basis for the coefficient ring is just the power basis
# in the root of the defining polynomial above.
hecke_ring_character_values = None
aps_data = [[-4096], [531441], [590425734], [57857417576], [9494266240140], [-134968021061458], [-2526114016804014], [11468758872260756], [113342630802000600], [1081348899350530974], [4649090467326833408], [-46093370056702003258], [51449233931826001194], [-369342639690619984084], [-49106637730499080080], [4440077625909370178934], [22549343358865698156540], [-12310641025418994171490], [6385919851217871016196], [60276767662482517683720], [-268812100727467655130358], [-262861199604551219808592], [688505757189913419282132], [-2558749855718408389837542], [2595207926228515475808482], [-17474179443895635988432602], [-13279828694538083126115064], [41795718405817412551106988], [46463961434676787351625870], [32739462923138416463854962], [-169226056831180852494757600], [19026220712878938854805060], [-34843289147279954386219254], [179180331360143245902565196], [-2462675765812953478786384746], [433645982336850278324148728], [-3540075918421116213005142658], [-6459784740017952428491365724], [-4484317771246210562682202200], [1219734140852760562903157358], [-20925766826147041832334585996], [-1488956062117583435810930026], [-31954554483335393220191866944], [31642698328059839319881512898], [-48208345534680432308064275706], [96388657120022169834797276648], [-72256693088847878376589668460], [-71997855564033671801589475840], [-413856085654737228526451819292], [-493767240528092386751358918970], [265748619139756484592608244522], [-243721759536083923367162376336], [-275487928956830095589246618638], [1208632444944560569018552938876], [-227636672214409776531791993598], [71922686545312223939681074440], [258877562859358679236133620494], [-1025316160477184383489825087696], [4947192920227465752600815741942], [-3590901319774881769349302186662], [4521736965478152252477246153692], [5670053281755725720279309292774], [-20524080887344225302440786272780], [23379722674296121780764750872760], [-3967672489428590084736579597958], [-6404822737159958516706405250242], [34594487808228598993315198136972], [-20333642770639396649241978256174], [14006144300627770253941371356892], [-18804128374602631783273999289410], [-105140337826543997319885035683614], [-23950769242917476993077268564184], [11681661592447449692070957726032], [-62965177262289462255988534965994], [79839397387608901441163909502716], [116202756578985317063228557848960], [194162201332338314824333934151174], [-156136192963481298310266245513362], [204402116048300098997870698959954], [-580073802753530321491242977964454], [95962242167578765480376543827620], [899239510154833991828442558746630], [48774528374230732479358317801840], [-343563276659783587353835821617614], [952703031535934878491037835564888], [331350196885771398770879387995452], [-1036096683348399144086028166329726], [2361037965053800862358381320475146], [-386492253334059571846520501400690], [-1136908516109969570118684840699664], [-1383637593973553327977278714157356], [2245444390595350927558310367217056], [5221211701450354573978737517629512], [2553790897052584684653865138620204], [723080123124519942196047170836916], [3391404432501458665114924299215544], [59678203907231539943882313111294], [690203602447274870385252124099338], [-836285527477142597741581033547380], [-17994580210647806819588174974365250], [-8890365875432681472385868417033308], [-30155130317838652883183154514356882], [-19589117048529114789992262118728012], [-1373874692064642778630090453060422], [-6795833606091876430305056101493380], [-45851732155351388503362862389481918], [17773851741041607960433540717808268], [83339203047867523639553253027550290], [-77584008513553375148951013113812584], [-60704458277496148845855580556032102], [14060918132387658281274188479563776], [112382349324439960225726633820322182], [-51927686136326768861970469215950550], [-4738769619919666733486082050795476], [-3767973733941161870465891483685928], [62189500503871507736427422611620930], [-27369770989518103704281457806037244], [-142583723970835429613533867605059256], [251493341343476149615280138656828878], [-123988322566144158160870783151062572], [228548671800042667955144119493532854], [209132680368839962594483376978430626], [-393166483329538925497068326046921306], [-101629346444653327962145425146612052], [493084048907081542884551925612222644], [682363827310310447224945367689386174], [-278374084727182572675797494923953242], [878509820182012714014307359475384080], [808758992427406004163456637163690552], [-244873164349785387957009447500111362], [948377575486047596285594306655610148], [-564636310784733536560597917320231064], [-289134078251162913989255410627146160], [-1582362336485134562781087519805184938], [-1929946514049898446331124805576416262], [100838611405299898597860261624564482], [2061690300546130095893628413495486022], [-1656227363711267876977684975101275884], [1708304448595039377602946118925400030], [1583370535728070194637019138975581866], [2165367397734486261319091956448028716], [-3497495594533696040832871357288086282], [-1056335694007432082017325131812496360], [-202228530256521220317484481371439748], [2376037253152146491846064582604699358], [2936302478469309575810791025094150024], [4864481716819189306774971904628241014], [6236744010325586240529058543016080602], [-2042464539886572579446801739373339684], [3831594645641431000775518343863953504], [8656003591541707652860562718297657422], [6202276256060527649310662491721350386], [-195836432195884868192272959993868684], [6063905290897453978964308752597554040], [7322943720976251232933384901179434764], [7083372173126201020277119225503086352], [6346982372381946668390261637056459384], [-22114215665143811003556202238390889246], [-20686988746594954637277724809232459414], [14794602317525859472026444433003464558], [18854350246811474478678998932953326196], [892812275514215938064959309779346746], [-5328305355903907999462430699449444504], [34080376460257637281366043154258593484], [-41617884314333519593285169988442458222], [15952081603812910085968417672749519576], [3154492541296017432883736315225585984], [11979434061948092850651302083490908166], [-4160753743716645372262912379436141838], [-40216101817366991723459145603837931914], [62547999880203978631564341002319802428], [32627736374108479102781698419365852894], [-47537685414630720887010047906784381816], [-52002000660153337135004512832843051830], [-67340656503140180580069576126362515984], [-36266989088535981044117244127047923622], [18825295157550016207939261322827253468], [65899327304836742404506808838606779302], [74609440958352199280756566294824314312], [108001042988986666898102992253151374], [146294680749208892504449209573103065248], [103445547762278700580277067765741032388], [33964512475797619859733183891700349990], [-62341698269033626963196694275361558774], [160133871127084056981023364287538004560], [-118189039487192863633301483130364955946], [58243632296104229249618321855435618942], [116582932593157149858560180079703830308], [-67715213811055277662508336839665214294], [-196612415961002380352934603364797880704], [-147590447476310765834656693310476043902], [115185089550480766220612171032127204172], [108412507940421543507385140031064442452], [297825893915415585407587045988281116510], [-129349946483134650033788703251223778716], [-22129141477514682989640216391568124054], [-372583553522826062402188425847183967950], [350492110844060128583573705007535515614], [101299939149080298412009653933473572290], [-304380721064154540749538521996530212024], [-343427463357933997429939004365000516722], [202041969352844565695219024948645074928], [-514776473707813080317936319842891637322], [-399356792916646324087951776105599159326], [-250517165336649395370904306645225242900], [-573224698387591227025878993104063546370], [-607973043040179553039446794504741895520], [1300287005660629115619630502276898290308], [882221331313608882808633079633264655690], [1167248076298087653085897159321466691212], [-364178996960899664735545963607805823342], [502601641218883966825858076208534515862], [-1464953125467842608499552024345209060936], [585505675234528875512154747382295579100], [-225469543429797745552610697147747544728], [1184698266385645248838807127512323410666], [-1421645279713841762627042450250282256240], [2358172729503043797599305960821464247954], [2243320409880878143770459631332316522584], [-602178761982413782737702050668393808994], [1465932024458011039522900240266373225670], [-1158669872449612968321656957850906409960], [2351940214037338197151604771543050368450], [3250355786959152306715489984465210659248], [-1791618851761384038493383315857326519788], [-3268805561586652146056551129209767811658], [-2066620934509212508222946711976001830054], [294327618257447107630261603911607805280], [3424797632152120806439281706762783864520], [3949032997896928799479075664551900268268], [-73878131148035376744415344521001425458], [-2606555028712762357272135911651597411020], [5015186241391225268693559405328682469344], [-7809009153492090290535230105630941436022], [2814690339711273970353487024605127127372], [-2989687859028279599878600536999742122864], [1564835081872181531803472864493645213650], [5314554174001464094391479986059291370966], [2203163182147068721233296833268130265308], [-1276233468443227105945432050827633127768], [-468766660927826497862955164829450106764], [-4813329318117825489596994567142875907780], [-10691313875462154884246239146294380115352], [-5644452925248638636989058403859539374482], [9779171325827063022594660595990615471506], [1686144790269031611666274491048715614552], [13732738116978642228040962397880493337088], [-4852711536280939495420991512710083593116], [-10393069575853087173922229277970410731668], [10893472937632723515847160710173321499056], [16751121788632904625701675599045685294558], [-19445141701415078301072518651845218011454], [-313863800293164331977269044612107992568], [-8888369844665071483134601946431650351094], [11126161289246391275753632508769090336846], [-732878189357353066380574334715179063148], [16004314948352146956624635386105178738486], [-24755711171356443322676569962777089591908], [10126798240425042968316164842433762717862], [-5204049087269662144692489043687696831558], [-11976011225126263406278260398891222230240], [-18573780656543055211827091043726660022972], [10013691062799738918285559688141349161702], [23992684328018581423048728395078152494206], [-9746276335691233014467879162330040146718], [32328092512221583495844321850460044736484], [-23856949080969993464757023210444457691410], [5847304322526962769976008275529701213562], [1218025732048931993668529844643959400124], [-8168971875522962315008688356466229719226], [51303140729152978614538622954920938601646], [24908908056903971854098013290748713177620], [31341480280645964468428115819193390398234], [-24581312380844519929660770909372067610560], [-28895392264959259428795831715912002995854], [23548044817934066121824188427091870729368], [39372338685811825797721462991566930905084], [-1427157789488332043955983614233735051682], [-32479927643100310895478455933429676306742], [-44693173905711276032782214426946101370540], [78111755994432977570117484884104560491232], [-56370247157128224646539029549238274129720], [-67064174345347000546617737086995118954632], [129335802249212730782025148261887411158630], [-41641183195825167646609611073963997588404], [6520105495752178377500432350422756183504], [72095678456006019067895184345044616904274], [146720694907364160132876012330830636035542], [35048064657720793398108792444735403742648], [31884066570523313156919240094177434468066], [26835531205259834463004229100859760683950], [-81696093601527539642292731220708516366540], [-26893672934768488513869346413932039616966], [-218704983355895520567670518701592724358580], [-76904989169485833834323861603479977438994], [192643500248302405839832779916387434049758], [-28986999857681540935437467009501660991424], [200238305546061521531277382634292668257782], [248187348682404860279947546464897091209660], [-237852259321408742865617041650783765138748], [-89956128378204122261057108109864043583350], [-241762763548947750578700277851995515572978], [-102829423665480947700788592798350759625040], [-189496288953391161091917785682992816659308], [176727672291893709461151372740379315025628], [-327675072397822434770599412015684425522846], [221021526287586587814618330545597542041708], [18233115156961135662791883854348584352654], [-19516561166109756542088920586873407871432], [-326739326509709493204264979550061727263706], [151842864746743475014323415359299358722832], [242528077954855344103369783614330253530966], [-480240630442088940108266115906611698343454], [230101833490698758226416485777540543392932], [77565451950009353347635078068318088234408], [191859122975572438627882602589584014761706], [107421634283850500970794840510613363262068], [169709276490986920055074518071940536210304], [-587359996628564071838244201221062666564030], [166157380222546871179155877091911875738450], [-611788623412548773190683434738990354980076], [-515532827471579212698610788001236361590118], [-553121165850917728338188004371071225779234], [564540542001710394311152481042067939857216], [-456169372174726803424716316518535218594966], [542348634641221065812614076211650615879282], [217636074381105633575312182532934428551940], [-396767117462936761422049228380099399350116], [599794825806629890276690065820004813316768], [-1093650945736296823368482879497796545339866], [109435338511548610190278766883222482563022], [-191784039916190537970771852263934939388674], [-721735871729452154937133852250414458374688], [1259722334677781590066567613386633969680900], [1431539601272946604428855285094836167643788], [-1517943586237010688091818445397921500708644], [653304677058037370808013384231255193153726], [-1451750344746691724476169651932028967437982], [726886261470894000185901200924139283993514], [853273220389570010937063098853966736603280], [1860596958317421131197536783035387387921174], [-1487107292643166310172646457770407371174022], [764976268429435243059403071058121452157382], [431128585577737380460608986455140686717480], [1312881479449910737600282972956674723647518], [1302388664781935890520374442411562019463844], [665865292866899658447414260699089656749318], [-209034233898237071077798691233201831025044], [236300348792652067635775538449840183283568], [-463780750565666781314391880183925003222538], [451865214333933514219096986123869136602180], [802132496630728612352126480451228096949130], [-1392435787201525955424963922821630289923378], [-1333064452266970694690867039700635443836688], [-1799211661972715843603894482153803145347466], [1373636565212130184836021829134286420183194], [-2089717394442588746998846847283795088358688], [-446349655492955759272195683249320023816788], [3399937433979194188194276185423901105000114], [-336078337077288896304568598452812631014408], [-3621588053080091143305679016542350143524570], [-574321978500822159199040801494867556308278], [-2363844116430976518869252550239312594440560], [1416023736174207193097086138095204590632860], [-2653520146940094117383973851659655205527068], [-3641107742208326577098811459379396065786262], [-389899950521551468778291231672516436566610], [1717191999245908144095652473129395789458088], [1379526267290237011882707411468755190616346], [1863242479274639822349677898072928673830116], [5238857951483368044332466965888276293842284], [6556425450661738635961399768076837419756272], [576470911785596597412269383495200466979382], [3055918491246133459003187960653367259550040], [6112781930717436172959709621738895384534558], [-2300430946878176500331265925084255681821036], [-8778543437414785833885870794892655123844832], [-6761697309056212137959494393942765357372126], [7602573281177246062875103578340124669947122], [-6165414530765159761007700326254441047785734], [-1453948081643802006023759171353582509854082], [-5391464597748727956045592223170052510949174], [-3017835527036632492908050124004557855702088], [3130384605730269488662858683807305657386338], [-7013447414531762645090740158692130095837212], [1584873431778218264992394890341795062906472], [2499206517301464634800065144590501815074768], [2754959073225842005913807080906779945953366], [1835204449905731167016976864938960241135932], [-12359314699089698305511386714052065731424704], [11769445804436850913444353269962242641973122], [6623115602065450634638173893999542343330694], [13040089442174240725212020500675672257072972], [-720650467948270440665831695939093396841452], [-743428354645127763223517028760545572524776], [120544493290217554518691587076072750619738], [-8118935720995169367319699713046202924083648], [4541873863133504682161340872678689959769002], [-207172942169575117612201564084981668839380], [-3675043258482015095253203649538705033776714], [-8744468128075599309811851527277783408507106], [-1837527551307510972752743028414143220605950], [10095686778820499724182817550309559483795312], [16290654742741140846575035647090168977727834], [5949828352403757975572123199723268622956710], [3883390698791105578813644659853509362562504], [-4774184201435731615321221104448327177964786], [692314214525030981306973992763717016787634], [-3210735235377342912925300103334625968725644], [-19610838689546127912207306201573481897712508], [22432020450995554262626669395052113415896722], [7471946218845863395716611666296533364337046], [25820876172862644060005124543815917461448860], [-8511025279571852413020755008058527704689116], [17038309883018138439287283374772909124859882], [-984830554409146395951407282832687171185106], [-9723752740175416690471875108587034035660736], [23491872176205308144135855258052675414429992], [-29399280374591905603847830147038000611992302], [-8487304969691315370940313937071028936901224], [15880521074320969151769602165406724004560542], [-11563591611814123622496348141969135017532154], [23814744021206654714757892721521261569330672], [-32465094840548821519583431144524477103526532], [9748582544899864119773528667748990279438922], [-28392195288054684355498263675853294916949618], [-43825292104186454910361533935961728582367084], [22029311137359699338233228249897374405076314], [-29800859786852025825556301306057435686285540], [-47952973064159994505688153987116386566459784]]
